import { getSystemInfoAsync } from '@/utils/system';
import store from '@/store';

const BASE_URL = 'https://test.chelvc.com';
const TIME_OUT = 60000;
const errStatus = {
  200: '成功',
  400: '请求参数异常',
  401: '用户认证失败，需要用户重新认证',
  403: '用户无访问权限',
  404: '访问的目标资源不存在',
  405: '请求方式不支持',
  406: '接口参数传递方式不支持',
  410: '用户令牌已被重置，需要用户重新登录',
  412: '参数校验异常，具体格式请查看响应参数格式',
  415: '接口媒体类型不支持',
  500: '服务端异常',
};
// const { osName, deviceId, osversion } = getSystemInfoAsync();

export function request(options) {
  uni.showLoading({
    title: options.loadingText || '加载中...',
  });
  return new Promise((resolve, reject) => {
    return uni.request({
      timeout: TIME_OUT,
      url: BASE_URL + options.url,
      method: options.method.toUpperCase() || 'GET',
      data: options.data,
      header: Object.assign(
        {},
        {
          'Content-Type': 'application/json; charset=utf-8',
          client_id: 'chelvc_client',
          client_secret: 'qWBe6jD%GCuPPTkP',
          grant_type: 'wechat',
          // Platform: osName.toUpperCase(),
          // Device: deviceId,
          // Version: osversion,
          // Terminal: 'APPLET',
        },
        options.header,
      ),
      success: res => {
        if (res.statusCode !== 200) {
          uni.showToast({
            icon: 'none',
            title: res.data.message || errStatus[res.statusCode],
            duration: 2000,
          });
          reject(res);
        } else {
          resolve(res.data);
        }
      },
      fail: err => {
        console.log('fail:err', err);
        if (err.errMsg.includes('timeout')) {
          uni.showToast({
            icon: 'none',
            title: '网络连接超时,请检查您的网络',
            duration: 2000,
          });
        }
        reject(err);
      },
      complete: () => {
        uni.hideLoading();
      },
    });
  });
}

export function send(options) {
  const access_token = store.getters.access_token;
  options.header['Authorization'] = `Bearer ${access_token}`;
  return request(options);
}
